pub struct ClientPrivateKey { /* private fields */ }Expand description
The private PRF key held by the client as they request credential issuance.
Implementations
Sourceimpl ClientPrivateKey
impl ClientPrivateKey
Sourcepub fn random(rng: impl CryptoRngCore) -> Self
pub fn random(rng: impl CryptoRngCore) -> Self
Generate a new client private key.
Sourcepub fn request<H: Hasher>(
&self,
params: &Params<H>,
rng: impl CryptoRngCore,
) -> CredentialRequest
pub fn request<H: Hasher>( &self, params: &Params<H>, rng: impl CryptoRngCore, ) -> CredentialRequest
Create a request for a new credential issuance associated to the given private key.
Sourceimpl ClientPrivateKey
impl ClientPrivateKey
Sourcepub fn create_credential(
&self,
request: &CredentialRequest,
response: &CredentialResponse,
issuer_public_key: &IssuerPublicKey,
) -> Option<Credential>
pub fn create_credential( &self, request: &CredentialRequest, response: &CredentialResponse, issuer_public_key: &IssuerPublicKey, ) -> Option<Credential>
Creates a new credential using the original request, response from the server, and the client’s private PRF key.