pub struct CredentialRequest { /* private fields */ }Expand description
The request sent to the server by the client, proving that they know their private key.
Implementations
Sourceimpl CredentialRequest
impl CredentialRequest
Sourcepub fn respond<H: Hasher>(
&self,
issuer_private_key: &IssuerPrivateKey,
params: &Params<H>,
rng: impl CryptoRngCore,
) -> Option<CredentialResponse>
pub fn respond<H: Hasher>( &self, issuer_private_key: &IssuerPrivateKey, params: &Params<H>, rng: impl CryptoRngCore, ) -> Option<CredentialResponse>
Responds to the given credential request with the data needed for the client to construct a new credential.